Class: PgEventstore::FeatureMarker

Inherits:
Object
  • Object
show all
Includes:
Extensions::OptionsExtension
Defined in:
lib/pg_eventstore/feature_marker.rb,
sig/pg_eventstore/feature_marker.rbs

Instance Attribute Summary collapse

Method Summary

Methods included from Extensions::OptionsExtension

included, #init_default_values, #initialize, #options_hash, #readonly!, #readonly?, #readonly_error

Instance Attribute Details

#descriptionString?

Returns the description of the maker. Can be used as human-friendly explanation of the purpose.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)

    the description of the maker. Can be used as human-friendly explanation of the purpose



13
# File 'lib/pg_eventstore/feature_marker.rb', line 13

attribute(:description)

#markerString

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/pg_eventstore/feature_marker.rb', line 10

attribute(:marker)

#purposeSymbol?

Returns the purpose of the maker. Can be used as an identifier in your implementation.

Parameters:

  • value (Symbol, nil)

Returns:

  • (Symbol, nil)

    the purpose of the maker. Can be used as an identifier in your implementation



16
# File 'lib/pg_eventstore/feature_marker.rb', line 16

attribute(:purpose)