Class: PgEventstore::SubscriptionFeeder

Inherits:
Object
  • Object
show all
Extended by:
Forwardable
Defined in:
lib/pg_eventstore/subscriptions/subscription_feeder.rb,
sig/pg_eventstore/subscriptions/subscription_feeder.rbs

Overview

This class is responsible for starting/stopping all SubscriptionRunners. The background runner of it is responsible for events pulling and feeding those SubscriptionRunners.

Constant Summary collapse

EVENTS_PULL_INTERVAL =

Determines how often to fetch events from the event store.

0.2