Class: PgEventstore::SubscriptionsSet

Inherits:
Object
  • Object
show all
Includes:
Extensions::OptionsExtension
Defined in:
lib/pg_eventstore/subscriptions/subscriptions_set.rb,
sig/pg_eventstore/subscriptions/subscriptions_set.rbs

Overview

Defines ruby's representation of subscriptions_set record.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Extensions::OptionsExtension

included

Constructor Details

#initializeSubscriptionsSet

Returns a new instance of SubscriptionsSet.

Parameters:

  • options (Object)


34
# File 'sig/pg_eventstore/subscriptions/subscriptions_set.rbs', line 34

def initialize: (**untyped options) -> void

Instance Attribute Details

#created_atTime?

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


54
# File 'lib/pg_eventstore/subscriptions/subscriptions_set.rb', line 54

attribute(:created_at)

#idInteger?

Returns It is used to lock the Subscription by updating Subscription#locked_by attribute.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)

    It is used to lock the Subscription by updating Subscription#locked_by attribute



26
# File 'lib/pg_eventstore/subscriptions/subscriptions_set.rb', line 26

attribute(:id)

#last_errorHash?

Returns the information about last error caused when pulling Subscriptions events.

Parameters:

  • value ({ 'class' => String, 'message' => String, 'backtrace' => Array[String] }, nil)

Returns:

  • (Hash, nil)

    the information about last error caused when pulling Subscriptions events.



48
# File 'lib/pg_eventstore/subscriptions/subscriptions_set.rb', line 48

attribute(:last_error)

#last_error_occurred_atTime?

Returns the time when the last error occurred.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)

    the time when the last error occurred



51
# File 'lib/pg_eventstore/subscriptions/subscriptions_set.rb', line 51

attribute(:last_error_occurred_at)

#last_restarted_atTime?

Returns last time the SubscriptionsSet was restarted.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)

    last time the SubscriptionsSet was restarted



44
# File 'lib/pg_eventstore/subscriptions/subscriptions_set.rb', line 44

attribute(:last_restarted_at)

#max_restarts_numberInteger?

Returns maximum number of times the SubscriptionsSet can be restarted.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)

    maximum number of times the SubscriptionsSet can be restarted



38
# File 'lib/pg_eventstore/subscriptions/subscriptions_set.rb', line 38

attribute(:max_restarts_number)

#nameString?

Returns name of the set.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)

    name of the set



29
# File 'lib/pg_eventstore/subscriptions/subscriptions_set.rb', line 29

attribute(:name)

#restart_countInteger?

Returns the number of SubscriptionsSet's restarts after its failure.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)

    the number of SubscriptionsSet's restarts after its failure



35
# File 'lib/pg_eventstore/subscriptions/subscriptions_set.rb', line 35

attribute(:restart_count)

#stateString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


32
# File 'lib/pg_eventstore/subscriptions/subscriptions_set.rb', line 32

attribute(:state)

#time_between_restartsInteger?

Returns interval in seconds between retries of failed SubscriptionsSet.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)

    interval in seconds between retries of failed SubscriptionsSet



41
# File 'lib/pg_eventstore/subscriptions/subscriptions_set.rb', line 41

attribute(:time_between_restarts)

#updated_atTime?

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


57
# File 'lib/pg_eventstore/subscriptions/subscriptions_set.rb', line 57

attribute(:updated_at)

Class Method Details

.create(attrs) ⇒ PgEventstore::SubscriptionsSet

@param attrs

Parameters:

  • attrs (::Hash[untyped, untyped])

Returns:



12
13
14
# File 'lib/pg_eventstore/subscriptions/subscriptions_set.rb', line 12

def create(attrs)
  new(**subscriptions_set_queries.create(attrs))
end

Instance Method Details

#==(other) ⇒ Boolean

@param another

Parameters:

  • another (Object)

Returns:

  • (Boolean)


105
106
107
108
109
# File 'lib/pg_eventstore/subscriptions/subscriptions_set.rb', line 105

def ==(other)
  return false unless other.is_a?(SubscriptionsSet)

  id == other.id
end

#assign_attributes(attrs) ⇒ ::Hash[untyped, untyped]

@param attrs

Parameters:

  • attrs (::Hash[untyped, untyped])

Returns:

  • (::Hash[untyped, untyped])


61
62
63
64
65
# File 'lib/pg_eventstore/subscriptions/subscriptions_set.rb', line 61

def assign_attributes(attrs)
  attrs.each do |attr, value|
    public_send("#{attr}=", value)
  end
end

#deletevoid

This method returns an undefined value.



74
75
76
# File 'lib/pg_eventstore/subscriptions/subscriptions_set.rb', line 74

def delete
  subscriptions_set_queries.delete(id)
end

#dupPgEventstore::SubscriptionsSet

Dup the current object without assigned connection



80
81
82
# File 'lib/pg_eventstore/subscriptions/subscriptions_set.rb', line 80

def dup
  SubscriptionsSet.new(**Utils.deep_dup(options_hash))
end

#eql?(other) ⇒ Boolean

@param another

Parameters:

  • another (Object)

Returns:

  • (Boolean)


97
98
99
100
101
# File 'lib/pg_eventstore/subscriptions/subscriptions_set.rb', line 97

def eql?(other)
  return false unless other.is_a?(SubscriptionsSet)

  hash == other.hash
end

#hashInteger

Returns:

  • (Integer)


91
92
93
# File 'lib/pg_eventstore/subscriptions/subscriptions_set.rb', line 91

def hash
  id.hash
end

#init_default_valuesvoid

This method returns an undefined value.

@param options

Parameters:

  • options (::Hash[untyped, untyped])


48
# File 'sig/pg_eventstore/subscriptions/subscriptions_set.rbs', line 48

def init_default_values: (::Hash[untyped, untyped] options) -> void

#options_hash::Hash[untyped, untyped]

Returns:

  • (::Hash[untyped, untyped])


36
# File 'sig/pg_eventstore/subscriptions/subscriptions_set.rbs', line 36

def options_hash: () -> ::Hash[untyped, untyped]

#readonly!Boolean

@param opt_name

Parameters:

  • opt_name (Symbol)

Returns:

  • (Boolean)


39
# File 'sig/pg_eventstore/subscriptions/subscriptions_set.rbs', line 39

def readonly!: (Symbol opt_name) -> bool

#readonly?Boolean

@param opt_name

Parameters:

  • opt_name (Symbol)

Returns:

  • (Boolean)


42
# File 'sig/pg_eventstore/subscriptions/subscriptions_set.rbs', line 42

def readonly?: (Symbol opt_name) -> bool

#readonly_errorvoid

This method returns an undefined value.

@param opt_name

Parameters:

  • opt_name (Symbol)


45
# File 'sig/pg_eventstore/subscriptions/subscriptions_set.rbs', line 45

def readonly_error: (Symbol opt_name) -> void

#reloadPgEventstore::SubscriptionsSet



85
86
87
88
# File 'lib/pg_eventstore/subscriptions/subscriptions_set.rb', line 85

def reload
  assign_attributes(subscriptions_set_queries.find!(id))
  self
end

#subscriptions_set_queriesPgEventstore::SubscriptionsSetQueries

Returns:

  • (PgEventstore::SubscriptionsSetQueries)


114
115
116
# File 'lib/pg_eventstore/subscriptions/subscriptions_set.rb', line 114

def subscriptions_set_queries
  SubscriptionsSetQueries.new(self.class.connection)
end

#update(attrs) ⇒ ::Hash[untyped, untyped]

@param attrs

Parameters:

  • attrs (::Hash[untyped, untyped])

Returns:

  • (::Hash[untyped, untyped])


69
70
71
# File 'lib/pg_eventstore/subscriptions/subscriptions_set.rb', line 69

def update(attrs)
  assign_attributes(subscriptions_set_queries.update(id, attrs))
end